
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.78'
version = '1.2.78'
full_version = '1.2.78'
git_revision = '320e95da671cc873bf8027c5d9d09e2be22aeeb7'
release = True

if not release:
    version = full_version
    short_version += ".dev"
